create_dispatch

Function create_dispatch 

pub fn create_dispatch(prog_id: &str) -> Result<ComDispatch, ComError>
Creates a COM object from a ProgID and returns it as a dispatch handle.

Errors

ComError::Hresult if the apartment cannot be initialized, the ProgID is unknown, or the class cannot be instantiated.